summaryrefslogtreecommitdiffstats
path: root/config/config.c
diff options
context:
space:
mode:
Diffstat (limited to 'config/config.c')
-rw-r--r--config/config.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/config/config.c b/config/config.c
index d2887ea4..ec8cdb69 100644
--- a/config/config.c
+++ b/config/config.c
@@ -61,8 +61,8 @@ Settings config = {
.window_key = "F12",
.run_key = "mod1+F2",
.ssh_key = "mod1+F3",
- // Location of the window. CENTER, NORTH_WEST, NORTH,NORTH_EAST, etc.
- .location = CENTER,
+ // Location of the window. WL_CENTER, WL_NORTH_WEST, WL_NORTH,WL_NORTH_EAST, etc.
+ .location = WL_CENTER,
// Mode of window, list (Vertical) or dmenu like (Horizontal)
.wmode = VERTICAL,
// Padding of the window.